setStatus method
Record the status of type, replacing any previous status for it.
Implementation
void setStatus(RPPermissionType type, RPPermissionStatus status) =>
statuses[type] = status;
Record the status of type, replacing any previous status for it.
void setStatus(RPPermissionType type, RPPermissionStatus status) =>
statuses[type] = status;