RPPermissionStatus enum

The outcome of requesting an RPPermissionType.

Inheritance
Available extensions

Values

granted → const RPPermissionStatus

The permission was granted by the participant.

denied → const RPPermissionStatus

The permission was denied. It can be asked for again.

permanentlyDenied → const RPPermissionStatus

The permission was denied and the OS will not show the dialog again. The participant has to grant it from the system settings.

restricted → const RPPermissionStatus

The OS does not allow this permission, e.g. due to parental controls.

unsupported → const RPPermissionStatus

The permission does not exist on this platform, or it is RPPermissionType.health and the section listed no RPConsentSection.healthDataTypes to ask for.

unknown → const RPPermissionStatus

The status could not be determined, e.g. because no platform implementation is available.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<RPPermissionStatus>
A constant List of the values in this enum, in order of their declaration.