RPStepResult constructor
RPStepResult({
- required String identifier,
- required RPAnswerFormat? answerFormat,
Returns an RPStepResult with a given identifier and an empty map of results.
It sets startDate to the DateTime.now(). Since these objects are instantiated
together with the Step it belongs to so it can be used for measuring how much
time the participant spent the given Step.
Implementation
RPStepResult({required String identifier, required this.answerFormat})
: super(identifier) {
this.results = Map();
startDate = DateTime.now();
}