RPPermissions class

Requests the OS permissions declared on the sections of a RPConsentDocument.

This is the only place in Research Package which talks to the platform about permissions. It is used by RPUIVisualConsentStep when the step has RPVisualConsentStep.askPermission set to true, but can also be called directly by an app which wants to ask for a permission outside a consent flow.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

request(RPPermissionType type, {List<HealthDataType> healthDataTypes = const []}) Future<RPPermissionStatus>
Asks the OS for type and returns the outcome.
requestHealthData(List<HealthDataType> types) Future<RPPermissionStatus>
Requests read access to health types and returns the outcome.