onBack property

VoidCallback? onBack
final

Returns to the previous step, or null on the first step of the task, where there is nothing to go back to.

Note that the default bar is stricter than this: it only offers BACK in an RPNavigableOrderedTask. A custom bar may offer it in a linear task too.

Implementation

final VoidCallback? onBack;