onNext property

VoidCallback? onNext
final

Advances to the next step, or null while the current step is not ready to be left — an unanswered question, typically.

Passing it straight to a button's onPressed therefore disables the button until the step is answered.

Implementation

final VoidCallback? onNext;