stepCount property

int stepCount
final

The number of steps in the task — for an RPNavigableOrderedTask not every step is necessarily shown, so it is an upper bound rather than an exact total.

Implementation

final int stepCount;