permissions property
The OS permissions which this section explains the need for.
They are requested when the participant taps "NEXT" on this section during
a RPVisualConsentStep which has RPVisualConsentStep.askPermission set
to true. This way the permission dialog is shown in context, with the
summary and content of this section as the rationale — which is what
both Apple and Google ask for.
If null or empty, no permissions are requested for this section.
Implementation
List<RPPermissionType>? permissions;