onCancel property
Cancels the task, after asking the participant to confirm in a dialog.
This is what the close button of the default carousel bar does. To end the task without confirmation, call RPUITask.onCancel directly and pop the route.
Implementation
final VoidCallback onCancel;